@@ -12,7 +12,7 @@ from textblob import TextBlob
 class process_text:
 
     def __init__(self):
-        self.__version__ = "2.1.0"
+        self.__version__ = "2.2.0"
         self.nlp = spacy.load("en_core_web_md")
         self.path = r".\\TextPreprocessing"
         self.abbreviations = {
@@ -363,7 +363,7 @@ class process_text:
         return " ".join([txt for txt in text.split() if txt not in stopwords])
     
     def correct_spelling(self, text):
-        return TextBlob(text).correct()
+        return str(TextBlob(text).correct())
     
     def clear_generic_entity(self, text):
         document = self.nlp(text)
